@@ -34,7 +34,7 @@ class BookEndpoints(PublicResourceEndpointSet):
     group_name = 'Book'
 
     @staticmethod
-    def authorize(principal, book_id: int = None, *args, **kwargs):
+    async def authorize(principal, book_id: int = None, *args, **kwargs):
         return True
 
     class singleton_subresource(PublicResourceEndpointSet):
