@@ -12,7 +12,7 @@ from ..ihttpauthenticationservice import IHTTPAuthenticationService
 
 
 class HTTPAuthenticationService(IHTTPAuthenticationService):
-    logger = logging.getLogger('unimatrix.auth')
+    logger = logging.getLogger('uvicorn')
 
     async def resolve(self,
         bearer: bytes,
@@ -81,7 +81,16 @@ class HTTPAuthenticationService(IHTTPAuthenticationService):
         except LookupError:
             if not jwt.iss or (jwt.iss == 'self'):
                 raise
+            self.logger.debug(
+                "Public key unknown, trying lookup (kid: %s, issuer: %s)",
+                kid, jwt.iss
+            )
             if attempts >= max_attempts:
+                self.logger.error(
+                    "Could not retrieve key after %s attempts "
+                    "(kid: %s, issuer: %s)",
+                    attempts, kid, jwt.iss
+                )
                 raise UpstreamServiceNotAvailable
             if attempts > 0:
                 self.logger.warning("Retrying JWKS lookup for %s", jwt.iss)
@@ -89,4 +98,6 @@ class HTTPAuthenticationService(IHTTPAuthenticationService):
                 ['oauth2.sts'],
                 {'oauth2/sts': jwt.iss}
             )
+            self.logger.debug("Retrieved public key (kid: %s, issuer: %s)",
+                kid, jwt.iss)
             return await self.get_public_key(kid, jwt, attempts+1)
