@@ -225,6 +225,16 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
     #: The class used to handle IAM.
     iam_class: type = EndpointIAM
 
+    @functools.cached_property
+    def qualname(self) -> str:
+        """The qualified name of the endpoint, including parent classes."""
+        return self.resource_name\
+            if self.parent_class is None\
+            else (
+                f"{str.join('.', [x.resource_name for x in self.get_ancestors()])}"
+                f".{self.resource_name}"
+            )
+
     def __init__(self, action, *args, **kwargs):
         self.action = action
 
@@ -577,14 +587,14 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
 
     def reverse(self, name: str, **params) -> str:
         """Reverses the given path relative to the current view."""
-        return self.request.url_for(f'{self.resource_name}.{name}', **params)
+        return self.request.url_for(f'{self.qualname}.{name}', **params)
 
     def get_detail_url(self, *args, **params) -> str:
         """Returns the detail view URL of the endpoint."""
         path_parameter = self.path_parameter.default
         if args:
             dto = args[0]
-            params = {path_parameter: dto[path_parameter]}
+            params = self._get_path_params_from_resource(dto)
         return self.reverse('retrieve', **params)
 
     def get_limit(self) -> int:
@@ -610,6 +620,15 @@ class ResourceEndpointSet(metaclass=ResourceEndpointSetMetaclass):
         """Return the offset for pagination from a request."""
         return self._get_int_query_param(self.request.query_params, 'offset', 0)
 
+    def get_ancestors(self) -> list:
+        """Return the list of ancestors."""
+        ancestors = []
+        parent = self.parent_class
+        while parent:
+            ancestors.append(parent)
+            parent = parent.parent_class
+        return ancestors
+
     def get_prev_url(self) -> str:
         """Return the previous URL for pagination, based on the current offset
         and limit.
